==> quantlib_1.15.orig.tar.gz: QuantLib-1.15/ql/experimental/averageois/makearithmeticaverageois.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2016 Stefano Fondi

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file makeois.hpp
    \brief Helper class to instantiate overnight indexed swaps.
*/

#ifndef quantlib_makearithmeticaverageois_hpp
#define quantlib_makearithmeticaverageois_hpp

#include <ql/experimental/averageois/arithmeticaverageois.hpp>
#include <ql/time/dategenerationrule.hpp>
#include <ql/termstructures/yieldtermstructure.hpp>

namespace QuantLib {

    //! helper class
    /*! This class provides a more comfortable way
        to instantiate arithemtic average overnight indexed swaps.
    */
    class MakeArithmeticAverageOIS {
      public:
        MakeArithmeticAverageOIS(const Period& swapTenor,
                const ext::shared_ptr<OvernightIndex>& overnightIndex,
                Rate fixedRate = Null<Rate>(),
                const Period& fwdStart = 0*Days);

        operator ArithmeticAverageOIS() const;
        operator ext::shared_ptr<ArithmeticAverageOIS>() const;

        MakeArithmeticAverageOIS& receiveFixed(bool flag = true);
        MakeArithmeticAverageOIS& withType(ArithmeticAverageOIS::Type type);
        MakeArithmeticAverageOIS& withNominal(Real n);

        MakeArithmeticAverageOIS& withSettlementDays(Natural settlementDays);
        MakeArithmeticAverageOIS& withEffectiveDate(const Date&);
        MakeArithmeticAverageOIS& withTerminationDate(const Date&);
        MakeArithmeticAverageOIS& withRule(DateGeneration::Rule r);

        MakeArithmeticAverageOIS& withFixedLegPaymentFrequency(Frequency f);
        MakeArithmeticAverageOIS& withOvernightLegPaymentFrequency(Frequency f);
        MakeArithmeticAverageOIS& withEndOfMonth(bool flag = true);

        MakeArithmeticAverageOIS& withFixedLegDayCount(const DayCounter& dc);

        MakeArithmeticAverageOIS& withOvernightLegSpread(Spread sp);

        MakeArithmeticAverageOIS& withDiscountingTermStructure(
                  const Handle<YieldTermStructure>& discountingTermStructure);
        MakeArithmeticAverageOIS& withPricingEngine(
                              const ext::shared_ptr<PricingEngine>& engine);
        MakeArithmeticAverageOIS& withArithmeticAverage(
                                       Real meanReversionSpeed = 0.03,
                                       Real volatility = 0.00, // NO convexity adjustment by default
                                       bool byApprox = false); // TRUE to use Katsumi Takada approximation
      private:
        Period swapTenor_;
        ext::shared_ptr<OvernightIndex> overnightIndex_;
        Rate fixedRate_;
        Period forwardStart_;

        Natural settlementDays_;
        Date effectiveDate_, terminationDate_;
        Calendar calendar_;

        Frequency fixedLegPaymentFrequency_;
        Frequency overnightLegPaymentFrequency_;
        DateGeneration::Rule rule_;
        bool endOfMonth_, isDefaultEOM_;

        bool byApprox_;
        Real mrs_;
        Real vol_;

        ArithmeticAverageOIS::Type type_;
        Real nominal_;

        Spread overnightSpread_;
        DayCounter fixedDayCount_;

        ext::shared_ptr<PricingEngine> engine_;
    };

}

#endif

==> quantlib_1.25.orig.tar.gz: QuantLib-1.25/ql/experimental/averageois/makearithmeticaverageois.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2016 Stefano Fondi

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file makeois.hpp
    \brief Helper class to instantiate overnight indexed swaps.
*/

#ifndef quantlib_makearithmeticaverageois_hpp
#define quantlib_makearithmeticaverageois_hpp

#include <ql/experimental/averageois/arithmeticaverageois.hpp>
#include <ql/time/dategenerationrule.hpp>
#include <ql/termstructures/yieldtermstructure.hpp>

namespace QuantLib {

    //! helper class
    /*! This class provides a more comfortable way
        to instantiate arithemtic average overnight indexed swaps.
    */
    class MakeArithmeticAverageOIS {
      public:
        MakeArithmeticAverageOIS(const Period& swapTenor,
                const ext::shared_ptr<OvernightIndex>& overnightIndex,
                Rate fixedRate = Null<Rate>(),
                const Period& fwdStart = 0*Days);

        operator ArithmeticAverageOIS() const;
        operator ext::shared_ptr<ArithmeticAverageOIS>() const;

        MakeArithmeticAverageOIS& receiveFixed(bool flag = true);
        MakeArithmeticAverageOIS& withType(Swap::Type type);
        MakeArithmeticAverageOIS& withNominal(Real n);

        MakeArithmeticAverageOIS& withSettlementDays(Natural settlementDays);
        MakeArithmeticAverageOIS& withEffectiveDate(const Date&);
        MakeArithmeticAverageOIS& withTerminationDate(const Date&);
        MakeArithmeticAverageOIS& withRule(DateGeneration::Rule r);

        MakeArithmeticAverageOIS& withFixedLegPaymentFrequency(Frequency f);
        MakeArithmeticAverageOIS& withOvernightLegPaymentFrequency(Frequency f);
        MakeArithmeticAverageOIS& withEndOfMonth(bool flag = true);

        MakeArithmeticAverageOIS& withFixedLegDayCount(const DayCounter& dc);

        MakeArithmeticAverageOIS& withOvernightLegSpread(Spread sp);

        MakeArithmeticAverageOIS& withDiscountingTermStructure(
                  const Handle<YieldTermStructure>& discountingTermStructure);
        MakeArithmeticAverageOIS& withPricingEngine(
                              const ext::shared_ptr<PricingEngine>& engine);
        MakeArithmeticAverageOIS& withArithmeticAverage(
                                       Real meanReversionSpeed = 0.03,
                                       Real volatility = 0.00, // NO convexity adjustment by default
                                       bool byApprox = false); // TRUE to use Katsumi Takada approximation
      private:
        Period swapTenor_;
        ext::shared_ptr<OvernightIndex> overnightIndex_;
        Rate fixedRate_;
        Period forwardStart_;

        Natural settlementDays_;
        Date effectiveDate_, terminationDate_;
        Calendar calendar_;

        Frequency fixedLegPaymentFrequency_;
        Frequency overnightLegPaymentFrequency_;
        DateGeneration::Rule rule_;
        bool endOfMonth_, isDefaultEOM_;

        bool byApprox_;
        Real mrs_;
        Real vol_;

        Swap::Type type_;
        Real nominal_;

        Spread overnightSpread_;
        DayCounter fixedDayCount_;

        ext::shared_ptr<PricingEngine> engine_;
    };

}

#endif
